getCategories() {
return categories;
diff --git a/src/main/java/com/rometools/propono/atom/common/rome/AppModule.java b/src/main/java/com/rometools/propono/atom/common/rome/AppModule.java
index 5811a90..dde22be 100644
--- a/src/main/java/com/rometools/propono/atom/common/rome/AppModule.java
+++ b/src/main/java/com/rometools/propono/atom/common/rome/AppModule.java
@@ -21,7 +21,7 @@ package com.rometools.propono.atom.common.rome;
import java.util.Date;
-import com.sun.syndication.feed.module.Module;
+import com.rometools.rome.feed.module.Module;
/**
* ROME Extension Module to Atom protocol extensions to Atom format.
diff --git a/src/main/java/com/rometools/propono/atom/common/rome/AppModuleGenerator.java b/src/main/java/com/rometools/propono/atom/common/rome/AppModuleGenerator.java
index 221a535..7f57b6d 100644
--- a/src/main/java/com/rometools/propono/atom/common/rome/AppModuleGenerator.java
+++ b/src/main/java/com/rometools/propono/atom/common/rome/AppModuleGenerator.java
@@ -29,8 +29,8 @@ import java.util.TimeZone;
import org.jdom2.Element;
import org.jdom2.Namespace;
-import com.sun.syndication.feed.module.Module;
-import com.sun.syndication.io.ModuleGenerator;
+import com.rometools.rome.feed.module.Module;
+import com.rometools.rome.io.ModuleGenerator;
/**
* Creates JDOM representation for APP Extension Module.
diff --git a/src/main/java/com/rometools/propono/atom/common/rome/AppModuleImpl.java b/src/main/java/com/rometools/propono/atom/common/rome/AppModuleImpl.java
index 273e8f6..c1a42e3 100644
--- a/src/main/java/com/rometools/propono/atom/common/rome/AppModuleImpl.java
+++ b/src/main/java/com/rometools/propono/atom/common/rome/AppModuleImpl.java
@@ -22,8 +22,8 @@ package com.rometools.propono.atom.common.rome;
import java.util.Date;
-import com.sun.syndication.feed.CopyFrom;
-import com.sun.syndication.feed.module.ModuleImpl;
+import com.rometools.rome.feed.CopyFrom;
+import com.rometools.rome.feed.module.ModuleImpl;
/**
* Bean representation of APP module.
diff --git a/src/main/java/com/rometools/propono/atom/common/rome/AppModuleParser.java b/src/main/java/com/rometools/propono/atom/common/rome/AppModuleParser.java
index 99ae4f0..a9d0e87 100644
--- a/src/main/java/com/rometools/propono/atom/common/rome/AppModuleParser.java
+++ b/src/main/java/com/rometools/propono/atom/common/rome/AppModuleParser.java
@@ -24,9 +24,9 @@ import java.util.Locale;
import org.jdom2.Element;
import org.jdom2.Namespace;
-import com.sun.syndication.feed.module.Module;
-import com.sun.syndication.io.ModuleParser;
-import com.sun.syndication.io.impl.DateParser;
+import com.rometools.rome.feed.module.Module;
+import com.rometools.rome.io.ModuleParser;
+import com.rometools.rome.io.impl.DateParser;
/**
* Parses APP module information from a JDOM element and into AppModule
form.
diff --git a/src/main/java/com/rometools/propono/atom/server/AtomException.java b/src/main/java/com/rometools/propono/atom/server/AtomException.java
index 8fe0930..c8d06e4 100644
--- a/src/main/java/com/rometools/propono/atom/server/AtomException.java
+++ b/src/main/java/com/rometools/propono/atom/server/AtomException.java
@@ -22,7 +22,7 @@ package com.rometools.propono.atom.server;
import javax.servlet.http.HttpServletResponse;
/**
- * Exception thrown by {@link com.sun.syndication.propono.atom.server.AtomHandler} and extended by
+ * Exception thrown by {@link com.rometools.rome.propono.atom.server.AtomHandler} and extended by
* other Propono Atom exception classes.
*/
public class AtomException extends Exception {
diff --git a/src/main/java/com/rometools/propono/atom/server/AtomHandlerFactory.java b/src/main/java/com/rometools/propono/atom/server/AtomHandlerFactory.java
index f8dd35b..3bd635f 100644
--- a/src/main/java/com/rometools/propono/atom/server/AtomHandlerFactory.java
+++ b/src/main/java/com/rometools/propono/atom/server/AtomHandlerFactory.java
@@ -22,14 +22,14 @@ import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
- * Defines a factory that enables the {@link com.sun.syndication.propono.atom.server.AtomServlet} to
- * obtain an {@link com.sun.syndication.propono.atom.server.AtomHandler} that handles an Atom
+ * Defines a factory that enables the {@link com.rometools.rome.propono.atom.server.AtomServlet} to
+ * obtain an {@link com.rometools.rome.propono.atom.server.AtomHandler} that handles an Atom
* request.
*
*
* To create your own Atom protocol implementation you must sub-class this class with your own
* factory that is capable of creating instances of your
- * {@link com.sun.syndication.propono.atom.server.AtomHandler} impementation.
+ * {@link com.rometools.rome.propono.atom.server.AtomHandler} impementation.
*
*/
public abstract class AtomHandlerFactory {
@@ -51,7 +51,7 @@ public abstract class AtomHandlerFactory {
* AtomHandlerFactory
implementation class to load:
*
* -
- * Use the
com.sun.syndication.propono.atom.server.AtomHandlerFactory
system
+ * Use the com.rometools.rome.propono.atom.server.AtomHandlerFactory
system
* property.
* -
* Use the properties file "/propono.properties" in the classpath. This configuration file is in
@@ -64,7 +64,7 @@ public abstract class AtomHandlerFactory {
* of any property in propono.properties after it has been read for the first time.
* -
* If not available, to determine the classname. The Services API will look for a classname in
- * the file:
META-INF/services/com.sun.syndication.AtomHandlerFactory
in jars
+ * the file: META-INF/services/com.rometools.rome.AtomHandlerFactory
in jars
* available to the runtime.
* -
* Platform default
AtomHandlerFactory
instance.
@@ -88,7 +88,7 @@ public abstract class AtomHandlerFactory {
}
/**
- * Creates a new instance of a {@link com.sun.syndication.propono.atom.server.AtomHandler} using
+ * Creates a new instance of a {@link com.rometools.rome.propono.atom.server.AtomHandler} using
* the currently configured parameters.
*
* @return A new instance of a AtomHandler.
diff --git a/src/main/java/com/rometools/propono/atom/server/FactoryConfigurationError.java b/src/main/java/com/rometools/propono/atom/server/FactoryConfigurationError.java
index 01acb69..62a1b98 100644
--- a/src/main/java/com/rometools/propono/atom/server/FactoryConfigurationError.java
+++ b/src/main/java/com/rometools/propono/atom/server/FactoryConfigurationError.java
@@ -17,7 +17,7 @@ package com.rometools.propono.atom.server;
/**
* Thrown when a problem with configuration with the
- * {@link com.sun.syndication.propono.atom.server.AtomHandlerFactory} exists. This error will
+ * {@link com.rometools.rome.propono.atom.server.AtomHandlerFactory} exists. This error will
* typically be thrown when the class of a parser factory specified in the system properties cannot
* be found or instantiated.
*/
diff --git a/src/main/java/com/rometools/propono/atom/server/FactoryFinder.java b/src/main/java/com/rometools/propono/atom/server/FactoryFinder.java
index b850c50..12f0b05 100644
--- a/src/main/java/com/rometools/propono/atom/server/FactoryFinder.java
+++ b/src/main/java/com/rometools/propono/atom/server/FactoryFinder.java
@@ -22,7 +22,7 @@ import java.io.InputStreamReader;
import java.util.Properties;
/**
- * Find {@link com.sun.syndication.propono.atom.server.AtomHandlerFactory} based on properties
+ * Find {@link com.rometools.rome.propono.atom.server.AtomHandlerFactory} based on properties
* files.
*/
class FactoryFinder {
diff --git a/src/main/java/com/rometools/propono/atom/server/impl/FileBasedAtomHandlerFactory.java b/src/main/java/com/rometools/propono/atom/server/impl/FileBasedAtomHandlerFactory.java
index d460371..f4cb6bc 100644
--- a/src/main/java/com/rometools/propono/atom/server/impl/FileBasedAtomHandlerFactory.java
+++ b/src/main/java/com/rometools/propono/atom/server/impl/FileBasedAtomHandlerFactory.java
@@ -22,8 +22,8 @@ import com.rometools.propono.atom.server.AtomHandler;
import com.rometools.propono.atom.server.AtomHandlerFactory;
/**
- * Extends {@link com.sun.syndication.propono.atom.server.AtomHandlerFactory} to create and return
- * {@link com.sun.syndication.propono.atom.server.impl.FileBasedAtomHandler}.
+ * Extends {@link com.rometools.rome.propono.atom.server.AtomHandlerFactory} to create and return
+ * {@link com.rometools.rome.propono.atom.server.impl.FileBasedAtomHandler}.
*/
public class FileBasedAtomHandlerFactory extends AtomHandlerFactory {
diff --git a/src/main/java/com/rometools/propono/blogclient/Blog.java b/src/main/java/com/rometools/propono/blogclient/Blog.java
index 5369eaa..eb5d505 100644
--- a/src/main/java/com/rometools/propono/blogclient/Blog.java
+++ b/src/main/java/com/rometools/propono/blogclient/Blog.java
@@ -45,7 +45,7 @@ public interface Blog {
* Get a single BlogEntry (or BlogResource) by token.
*
* @param token Token from blog entry's getToken() method.
- * @throws com.sun.syndication.propono.blogclient.BlogClientException On error fetching the blog
+ * @throws com.rometools.rome.propono.blogclient.BlogClientException On error fetching the blog
* entry.
* @return Blog entry specified by token.
*/
diff --git a/src/main/java/com/rometools/propono/blogclient/atomprotocol/AtomCollection.java b/src/main/java/com/rometools/propono/blogclient/atomprotocol/AtomCollection.java
index 72eddec..d944b89 100644
--- a/src/main/java/com/rometools/propono/blogclient/atomprotocol/AtomCollection.java
+++ b/src/main/java/com/rometools/propono/blogclient/atomprotocol/AtomCollection.java
@@ -27,7 +27,7 @@ import com.rometools.propono.blogclient.Blog;
import com.rometools.propono.blogclient.BlogClientException;
import com.rometools.propono.blogclient.BlogEntry;
import com.rometools.propono.blogclient.BlogResource;
-import com.sun.syndication.feed.atom.Category;
+import com.rometools.rome.feed.atom.Category;
/**
* Atom protocol implementation of BlogClient Blog.Collection.
diff --git a/src/main/java/com/rometools/propono/blogclient/atomprotocol/AtomEntry.java b/src/main/java/com/rometools/propono/blogclient/atomprotocol/AtomEntry.java
index af53fb3..945473b 100644
--- a/src/main/java/com/rometools/propono/blogclient/atomprotocol/AtomEntry.java
+++ b/src/main/java/com/rometools/propono/blogclient/atomprotocol/AtomEntry.java
@@ -26,10 +26,10 @@ import com.rometools.propono.blogclient.BaseBlogEntry;
import com.rometools.propono.blogclient.BlogClientException;
import com.rometools.propono.blogclient.BlogEntry;
import com.rometools.propono.utils.ProponoException;
-import com.sun.syndication.feed.atom.Entry;
-import com.sun.syndication.feed.atom.Link;
-import com.sun.syndication.feed.module.Module;
-import com.sun.syndication.feed.synd.SyndPerson;
+import com.rometools.rome.feed.atom.Entry;
+import com.rometools.rome.feed.atom.Link;
+import com.rometools.rome.feed.module.Module;
+import com.rometools.rome.feed.synd.SyndPerson;
/**
* Atom protocol implementation of BlogEntry.
@@ -135,8 +135,8 @@ public class AtomEntry extends BaseBlogEntry implements BlogEntry {
}
}
}
- final List contents = entry.getContents();
- com.sun.syndication.feed.atom.Content romeContent = null;
+ final List contents = entry.getContents();
+ com.rometools.rome.feed.atom.Content romeContent = null;
if (contents != null && !contents.isEmpty()) {
romeContent = contents.get(0);
}
@@ -147,8 +147,8 @@ public class AtomEntry extends BaseBlogEntry implements BlogEntry {
}
if (entry.getCategories() != null) {
final List cats = new ArrayList();
- final List romeCats = entry.getCategories();
- for (final com.sun.syndication.feed.atom.Category romeCat : romeCats) {
+ final List romeCats = entry.getCategories();
+ for (final com.rometools.rome.feed.atom.Category romeCat : romeCats) {
final BlogEntry.Category cat = new BlogEntry.Category();
cat.setId(romeCat.getTerm());
cat.setUrl(romeCat.getScheme());
@@ -159,7 +159,7 @@ public class AtomEntry extends BaseBlogEntry implements BlogEntry {
}
final List authors = entry.getAuthors();
if (authors != null && !authors.isEmpty()) {
- final com.sun.syndication.feed.atom.Person romeAuthor = (com.sun.syndication.feed.atom.Person) authors.get(0);
+ final com.rometools.rome.feed.atom.Person romeAuthor = (com.rometools.rome.feed.atom.Person) authors.get(0);
if (romeAuthor != null) {
author = new Person();
author.setName(romeAuthor.getName());
@@ -184,7 +184,7 @@ public class AtomEntry extends BaseBlogEntry implements BlogEntry {
}
entry.setTitle(title);
if (author != null) {
- final com.sun.syndication.feed.atom.Person person = new com.sun.syndication.feed.atom.Person();
+ final com.rometools.rome.feed.atom.Person person = new com.rometools.rome.feed.atom.Person();
person.setName(author.getName());
person.setEmail(author.getEmail());
person.setUrl(author.getUrl());
@@ -193,17 +193,17 @@ public class AtomEntry extends BaseBlogEntry implements BlogEntry {
entry.setAuthors(authors);
}
if (content != null) {
- final com.sun.syndication.feed.atom.Content romeContent = new com.sun.syndication.feed.atom.Content();
+ final com.rometools.rome.feed.atom.Content romeContent = new com.rometools.rome.feed.atom.Content();
romeContent.setValue(content.getValue());
romeContent.setType(content.getType());
- final List contents = new ArrayList();
+ final List contents = new ArrayList();
contents.add(romeContent);
entry.setContents(contents);
}
if (categories != null) {
- final List romeCats = new ArrayList();
+ final List romeCats = new ArrayList();
for (final Category cat : categories) {
- final com.sun.syndication.feed.atom.Category romeCategory = new com.sun.syndication.feed.atom.Category();
+ final com.rometools.rome.feed.atom.Category romeCategory = new com.rometools.rome.feed.atom.Category();
romeCategory.setTerm(cat.getId());
romeCategory.setScheme(cat.getUrl());
romeCategory.setLabel(cat.getName());
diff --git a/src/main/java/com/rometools/propono/blogclient/atomprotocol/AtomResource.java b/src/main/java/com/rometools/propono/blogclient/atomprotocol/AtomResource.java
index 97a0d3c..59ccf60 100644
--- a/src/main/java/com/rometools/propono/blogclient/atomprotocol/AtomResource.java
+++ b/src/main/java/com/rometools/propono/blogclient/atomprotocol/AtomResource.java
@@ -25,7 +25,7 @@ import com.rometools.propono.atom.client.ClientMediaEntry;
import com.rometools.propono.blogclient.BlogClientException;
import com.rometools.propono.blogclient.BlogEntry;
import com.rometools.propono.blogclient.BlogResource;
-import com.sun.syndication.feed.atom.Link;
+import com.rometools.rome.feed.atom.Link;
/**
* Atom protocol implementation of BlogResource.
diff --git a/src/test/java/com/rometools/propono/atom/client/AtomClientTest.java b/src/test/java/com/rometools/propono/atom/client/AtomClientTest.java
index 468ce57..58739e3 100644
--- a/src/test/java/com/rometools/propono/atom/client/AtomClientTest.java
+++ b/src/test/java/com/rometools/propono/atom/client/AtomClientTest.java
@@ -30,8 +30,8 @@ import org.slf4j.LoggerFactory;
import com.rometools.propono.atom.common.Categories;
import com.rometools.propono.atom.common.Collection;
import com.rometools.propono.utils.ProponoException;
-import com.sun.syndication.feed.atom.Category;
-import com.sun.syndication.feed.atom.Content;
+import com.rometools.rome.feed.atom.Category;
+import com.rometools.rome.feed.atom.Content;
/**
* Simple APP test designed to run against a live Atom server.
diff --git a/src/test/java/com/rometools/propono/atom/client/BloggerDotComTest.java b/src/test/java/com/rometools/propono/atom/client/BloggerDotComTest.java
index fc02902..b1aa31b 100644
--- a/src/test/java/com/rometools/propono/atom/client/BloggerDotComTest.java
+++ b/src/test/java/com/rometools/propono/atom/client/BloggerDotComTest.java
@@ -23,7 +23,7 @@ import junit.framework.TestSuite;
import org.junit.Ignore;
-import com.sun.syndication.feed.atom.Content;
+import com.rometools.rome.feed.atom.Content;
/**
* Simple APP test designed to run against Blogger.com.
diff --git a/src/test/java/com/rometools/propono/atom/common/CollectionTest.java b/src/test/java/com/rometools/propono/atom/common/CollectionTest.java
index fb05fee..267f85c 100644
--- a/src/test/java/com/rometools/propono/atom/common/CollectionTest.java
+++ b/src/test/java/com/rometools/propono/atom/common/CollectionTest.java
@@ -39,7 +39,7 @@ public class CollectionTest extends TestCase {
}
/**
- * Test of accepts method, of class com.sun.syndication.propono.atom.common.Collection.
+ * Test of accepts method, of class com.rometools.rome.propono.atom.common.Collection.
*/
public void testAccepts() {
diff --git a/src/test/java/com/rometools/propono/atom/server/AtomClientServerTest.java b/src/test/java/com/rometools/propono/atom/server/AtomClientServerTest.java
index 3f8e292..c68752d 100644
--- a/src/test/java/com/rometools/propono/atom/server/AtomClientServerTest.java
+++ b/src/test/java/com/rometools/propono/atom/server/AtomClientServerTest.java
@@ -45,8 +45,8 @@ import com.rometools.propono.atom.common.Categories;
import com.rometools.propono.atom.common.Collection;
import com.rometools.propono.atom.common.Workspace;
import com.rometools.propono.utils.ProponoException;
-import com.sun.syndication.feed.atom.Category;
-import com.sun.syndication.feed.atom.Content;
+import com.rometools.rome.feed.atom.Category;
+import com.rometools.rome.feed.atom.Content;
/**
* Test Propono Atom Client against Atom Server via Jetty. Extends AtomClientTest
to
diff --git a/src/test/java/com/rometools/propono/blogclient/SimpleBlogClientTest.java b/src/test/java/com/rometools/propono/blogclient/SimpleBlogClientTest.java
index 0d04035..55ae45c 100644
--- a/src/test/java/com/rometools/propono/blogclient/SimpleBlogClientTest.java
+++ b/src/test/java/com/rometools/propono/blogclient/SimpleBlogClientTest.java
@@ -28,7 +28,7 @@ import org.slf4j.LoggerFactory;
import com.rometools.propono.blogclient.Blog.Collection;
import com.rometools.propono.utils.Utilities;
-import com.sun.syndication.io.impl.Atom10Parser;
+import com.rometools.rome.io.impl.Atom10Parser;
/**
* Tests Atom and MetaWeblog API CRUD via BlogClient. Exclude this from automated tests because it
diff --git a/src/main/java/com/rometools/propono/atom/server/AtomHandler.java b/src/main/java/com/rometools/propono/atom/server/AtomHandler.java
index 6a5b061..f08762b 100644
--- a/src/main/java/com/rometools/propono/atom/server/AtomHandler.java
+++ b/src/main/java/com/rometools/propono/atom/server/AtomHandler.java
@@ -21,15 +21,15 @@ package com.rometools.propono.atom.server;
import com.rometools.propono.atom.common.AtomService;
import com.rometools.propono.atom.common.Categories;
-import com.sun.syndication.feed.atom.Entry;
-import com.sun.syndication.feed.atom.Feed;
+import com.rometools.rome.feed.atom.Entry;
+import com.rometools.rome.feed.atom.Feed;
/**
* Interface for handling single Atom protocol requests.
*
*
* To create your own Atom protocol implementation you must implement this interface and create a
* concrete sub-class of {@link com.sun.syndication.propono.atom.server.AtomHandlerFactory} which is
* capable of instantiating it.
*
*/
@@ -40,10 +40,10 @@ public interface AtomHandler {
public String getAuthenticatedUsername();
/**
* Return {@link com.sun.syndication.propono.atom.common.AtomService} object that contains the
* {@link com.sun.syndication.propono.atom.common.Workspace} objects available to the currently
* authenticated user and within those the
- * {@link com.sun.syndication.propono.atom.common.Collection} avalaible.
+ * {@link com.rometools.rome.propono.atom.common.Collection} avalaible.
*/
public AtomService getAtomService(AtomRequest req) throws AtomException;
@@ -21,15 +21,15 @@ package com.rometools.propono.atom.server;
*
* To create your own Atom protocol implementation you must implement this interface and create a
- * concrete sub-class of {@link com.sun.syndication.propono.atom.server.AtomHandlerFactory} which is
+ * concrete sub-class of {@link com.rometools.rome.propono.atom.server.AtomHandlerFactory} which is
* capable of instantiating it.
*
@@ -40,10 +40,10 @@ public interface AtomHandler {
public String getAuthenticatedUsername();
/**
- * Return {@link com.sun.syndication.propono.atom.common.AtomService} object that contains the
- * {@link com.sun.syndication.propono.atom.common.Workspace} objects available to the currently
+ * Return {@link com.rometools.rome.propono.atom.common.AtomService} object that contains the
+ * {@link com.rometools.rome.propono.atom.common.Workspace} objects available to the currently
* authenticated user and within those the
diff --git a/src/main/java/com/rometools/propono/atom/server/AtomServlet.java b/src/main/java/com/rometools/propono/atom/server/AtomServlet.java
index b440b15..9933f33 100644
--- a/src/main/java/com/rometools/propono/atom/server/AtomServlet.java
+++ b/src/main/java/com/rometools/propono/atom/server/AtomServlet.java
@@ -41,18 +41,18 @@ import org.slf4j.LoggerFactory;
import com.rometools.propono.atom.common.AtomService;
import com.rometools.propono.atom.common.Categories;
import com.rometools.propono.utils.Utilities;
-import com.sun.syndication.feed.atom.Content;
-import com.sun.syndication.feed.atom.Entry;
-import com.sun.syndication.feed.atom.Feed;
-import com.sun.syndication.feed.atom.Link;
-import com.sun.syndication.io.WireFeedOutput;
-import com.sun.syndication.io.impl.Atom10Generator;
-import com.sun.syndication.io.impl.Atom10Parser;
+import com.rometools.rome.feed.atom.Content;
+import com.rometools.rome.feed.atom.Entry;
+import com.rometools.rome.feed.atom.Feed;
+import com.rometools.rome.feed.atom.Link;
+import com.rometools.rome.io.WireFeedOutput;
+import com.rometools.rome.io.impl.Atom10Generator;
+import com.rometools.rome.io.impl.Atom10Parser;
/**
* Atom Servlet implements Atom protocol by calling an
* {@link com.sun.syndication.propono.atom.server.AtomHandler} implementation. This servlet takes
* care of parsing incoming XML into ROME Atom {@link com.sun.syndication.feed.atom.Entry} objects,
* passing those to the handler and serializing to the response the entries and feeds returned by
* the handler.
*/
@@ -41,18 +41,18 @@ import org.slf4j.LoggerFactory;
/**
* Atom Servlet implements Atom protocol by calling an
- * {@link com.sun.syndication.propono.atom.server.AtomHandler} implementation. This servlet takes
- * care of parsing incoming XML into ROME Atom {@link com.sun.syndication.feed.atom.Entry} objects,
+ * {@link com.rometools.rome.propono.atom.server.AtomHandler} implementation. This servlet takes
+ * care of parsing incoming XML into ROME Atom {@link com.rometools.rome.feed.atom.Entry} objects,
* passing those to the handler and serializing to the response the entries and feeds returned by
* the handler.
diff --git a/src/main/java/com/rometools/propono/atom/server/impl/FileBasedAtomHandler.java b/src/main/java/com/rometools/propono/atom/server/impl/FileBasedAtomHandler.java
index b1e0b9c..dc754da 100644
--- a/src/main/java/com/rometools/propono/atom/server/impl/FileBasedAtomHandler.java
+++ b/src/main/java/com/rometools/propono/atom/server/impl/FileBasedAtomHandler.java
@@ -32,13 +32,13 @@ import com.rometools.propono.atom.server.AtomHandler;
import com.rometools.propono.atom.server.AtomMediaResource;
import com.rometools.propono.atom.server.AtomRequest;
import com.rometools.propono.atom.server.AtomServlet;
-import com.sun.syndication.feed.atom.Entry;
-import com.sun.syndication.feed.atom.Feed;
+import com.rometools.rome.feed.atom.Entry;
+import com.rometools.rome.feed.atom.Feed;
/**
* File-based {@link com.sun.syndication.propono.atom.server.AtomHandler} implementation that stores
* entries and media-entries to disk. Implemented using
- * {@link com.sun.syndication.propono.atom.server.impl.FileBasedAtomService}.
+ * {@link com.rometools.rome.propono.atom.server.impl.FileBasedAtomService}.
*/
public class FileBasedAtomHandler implements AtomHandler {
@@ -118,7 +118,7 @@ public class FileBasedAtomHandler implements AtomHandler {
/**
* Return introspection document
*
* @throws com.sun.syndication.propono.atom.server.AtomException Unexpected exception.
* @return AtomService object with workspaces and collections.
*/
@Override
@@ -129,7 +129,7 @@ public class FileBasedAtomHandler implements AtomHandler {
/**
* Returns null because we use in-line categories.
*
* @throws com.sun.syndication.propono.atom.server.AtomException Unexpected exception.
* @return Categories object
*/
@Override
@@ -147,7 +147,7 @@ public class FileBasedAtomHandler implements AtomHandler {
*
* @param areq Details of HTTP request
* @return ROME feed representing collection.
* @throws com.sun.syndication.propono.atom.server.AtomException Invalid collection or other
* exception.
*/
@Override
@@ -166,7 +166,7 @@ public class FileBasedAtomHandler implements AtomHandler {
*
* @param entry Entry to be added to collection.
* @param areq Details of HTTP request
* @throws com.sun.syndication.propono.atom.server.AtomException On invalid collection or other
* error.
* @return Entry as represented on server.
*/
@@ -191,7 +191,7 @@ public class FileBasedAtomHandler implements AtomHandler {
* Get entry specified by pathInfo.
*
* @param areq Details of HTTP request
* @throws com.sun.syndication.propono.atom.server.AtomException On invalid pathinfo or other
* error.
* @return ROME Entry object.
*/
@@ -219,7 +219,7 @@ public class FileBasedAtomHandler implements AtomHandler {
*
* @param entry
* @param areq Details of HTTP request
- * @throws com.sun.syndication.propono.atom.server.AtomException
+ * @throws com.rometools.rome.propono.atom.server.AtomException
*/
@Override
public void putEntry(final AtomRequest areq, final Entry entry) throws AtomException {
@@ -32,13 +32,13 @@ import com.rometools.propono.atom.server.AtomHandler;
/**
- * File-based {@link com.sun.syndication.propono.atom.server.AtomHandler} implementation that stores
+ * File-based {@link com.rometools.rome.propono.atom.server.AtomHandler} implementation that stores
* entries and media-entries to disk. Implemented using
@@ -118,7 +118,7 @@ public class FileBasedAtomHandler implements AtomHandler {
* Return introspection document
*
- * @throws com.sun.syndication.propono.atom.server.AtomException Unexpected exception.
+ * @throws com.rometools.rome.propono.atom.server.AtomException Unexpected exception.
* @return AtomService object with workspaces and collections.
*/
@@ -129,7 +129,7 @@ public class FileBasedAtomHandler implements AtomHandler {
* Returns null because we use in-line categories.
*
- * @throws com.sun.syndication.propono.atom.server.AtomException Unexpected exception.
+ * @throws com.rometools.rome.propono.atom.server.AtomException Unexpected exception.
* @return Categories object
*/
@@ -147,7 +147,7 @@ public class FileBasedAtomHandler implements AtomHandler {
* @param areq Details of HTTP request
* @return ROME feed representing collection.
- * @throws com.sun.syndication.propono.atom.server.AtomException Invalid collection or other
+ * @throws com.rometools.rome.propono.atom.server.AtomException Invalid collection or other
* exception.
*/
@@ -166,7 +166,7 @@ public class FileBasedAtomHandler implements AtomHandler {
* @param entry Entry to be added to collection.
* @param areq Details of HTTP request
- * @throws com.sun.syndication.propono.atom.server.AtomException On invalid collection or other
+ * @throws com.rometools.rome.propono.atom.server.AtomException On invalid collection or other
* error.
* @return Entry as represented on server.
@@ -191,7 +191,7 @@ public class FileBasedAtomHandler implements AtomHandler {
*
* @param areq Details of HTTP request
- * @throws com.sun.syndication.propono.atom.server.AtomException On invalid pathinfo or other
+ * @throws com.rometools.rome.propono.atom.server.AtomException On invalid pathinfo or other
* error.
* @return ROME Entry object.
diff --git a/src/main/java/com/rometools/propono/atom/server/impl/FileBasedCollection.java b/src/main/java/com/rometools/propono/atom/server/impl/FileBasedCollection.java
index 26efd37..ab296c7 100644
--- a/src/main/java/com/rometools/propono/atom/server/impl/FileBasedCollection.java
+++ b/src/main/java/com/rometools/propono/atom/server/impl/FileBasedCollection.java
@@ -46,18 +46,18 @@ import com.rometools.propono.atom.server.AtomException;
import com.rometools.propono.atom.server.AtomMediaResource;
import com.rometools.propono.atom.server.AtomNotFoundException;
import com.rometools.propono.utils.Utilities;
-import com.sun.syndication.feed.WireFeed;
-import com.sun.syndication.feed.atom.Category;
-import com.sun.syndication.feed.atom.Content;
-import com.sun.syndication.feed.atom.Entry;
-import com.sun.syndication.feed.atom.Feed;
-import com.sun.syndication.feed.atom.Link;
-import com.sun.syndication.feed.module.Module;
-import com.sun.syndication.io.FeedException;
-import com.sun.syndication.io.WireFeedInput;
-import com.sun.syndication.io.WireFeedOutput;
-import com.sun.syndication.io.impl.Atom10Generator;
-import com.sun.syndication.io.impl.Atom10Parser;
+import com.rometools.rome.feed.WireFeed;
+import com.rometools.rome.feed.atom.Category;
+import com.rometools.rome.feed.atom.Content;
+import com.rometools.rome.feed.atom.Entry;
+import com.rometools.rome.feed.atom.Feed;
+import com.rometools.rome.feed.atom.Link;
+import com.rometools.rome.feed.module.Module;
+import com.rometools.rome.io.FeedException;
+import com.rometools.rome.io.WireFeedInput;
+import com.rometools.rome.io.WireFeedOutput;
+import com.rometools.rome.io.impl.Atom10Generator;
+import com.rometools.rome.io.impl.Atom10Parser;
/**
* File based Atom collection implementation. This is the heart of the file-based Atom service
@@ -121,7 +121,7 @@ public class FileBasedCollection extends Collection {
/**
* Get feed document representing collection.
*
* @throws com.sun.syndication.propono.atom.server.AtomException On error retrieving feed file.
* @return Atom Feed representing collection.
*/
public Feed getFeedDocument() throws AtomException {
@@ -121,7 +121,7 @@ public class FileBasedCollection extends Collection {
* Get feed document representing collection.
*
- * @throws com.sun.syndication.propono.atom.server.AtomException On error retrieving feed file.
+ * @throws com.rometools.rome.propono.atom.server.AtomException On error retrieving feed file.
* @return Atom Feed representing collection.
*/